@@ -2,7 +2,7 @@
 Date         : 2022-12-18 12:33:46
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-12-20 17:34:46
+LastEditTime : 2022-12-21 11:15:15
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\windspeed.py
@@ -20,12 +20,12 @@ import time
 
 
 def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
-    if o2==3:
-        X=42 # distance from an overwater loaction to the shore, or fetch length (km)
-    if o2==4 or o2==3:    
-        Xlat=-44 # average latitude of fetch (+: for the Northern hemisphere, -: for the Southern hemisphere); required when o2 = 4 or 3   
-    if o2==4: 
-        Rg=.7 # Rg=U10/Ug, read from Figure II-2-13 in CEM 2015
+    # if o2==3:
+    #     X=42 # distance from an overwater loaction to the shore, or fetch length (km)
+    # if o2==4 or o2==3:    
+    #     Xlat=-44 # average latitude of fetch (+: for the Northern hemisphere, -: for the Southern hemisphere); required when o2 = 4 or 3   
+    # if o2==4: 
+    #     Rg=.7 # Rg=U10/Ug, read from Figure II-2-13 in CEM 2015
     
     # Secondary (default)
     tol=0.0001 # Iteration tolerance
@@ -129,6 +129,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
         section1.extend(['大气表面层的稳定性状态：不稳定'])
 
     section2 = []
+    section2_note = []
     # section2.extend(['---滨水工的风速计算方法---'])
     nn=0 # order number of notes
     ssBD1=0 # for B-D
@@ -192,9 +193,9 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             #Ug=Ufl/.0275
             plt.axvline(Ug,ls="--",color="blue",linewidth=0.5,label='推算的'+str(round(atm))+'-min $U_g$ (自由大气中)')
             # nn=nn+1
-            section2.extend(['陆域风速对数分布律参数： 摩擦风速U*='+str(round(Ufl,3))+'m/s'])
+            section2.extend(['陆域风速对数分布律参数： 摩擦风速U*= '+str(round(Ufl,3))+' m/s'])
             # nn=nn+1
-            section2.extend(['根据已知陆域风推算的地转风速Ug='+str(round(Ug,3))+'m/s'])            
+            section2.extend(['根据已知陆域风推算的地转风速Ug= '+str(round(Ug,3))+' m/s'])            
         if o2==4:
             Ug=U # geostrophic windspeed (measured)
             plt.axvline(Ug,ls="--",color="blue",linewidth=0.5,label='已知的'+str(round(atm))+'-min $U_{g}$ (自由大气中)')
@@ -456,7 +457,7 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             Up1n=RF*np.array(Up1n) 
             Up2n=RF*np.array(Up2n)    
         # nn=nn+1
-        section2.extend(['陆上风进入水域后随风距的增大系数RF='+str(round(RF,2))+'. 最终的KEYPS和B-D结果均已考虑RF。'])    
+        section2.extend(['陆上风进入水域后随风距的增大系数RF= '+str(round(RF,2))+' . 最终的KEYPS和B-D结果均已考虑RF。'])    
 
     if o2==2 or o2==3:
         plt.scatter(U,zw,c="blue",marker="*",s=50,edgecolors="blue",label='已知的'+str(round(atm))+'-min陆上风速及对应高度')
@@ -473,27 +474,27 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             
     # nn=nn+1
     if dT==0:
-        section2.extend(['水域风速廓线参数： 粗糙度z0='+str(round(z0*1000,2))+'mm, 摩擦风速U*='+str(round(Uf,3))+'m/s'])
+        section2.extend(['水域风速廓线参数： 粗糙度z0= '+str(round(z0*1000,2))+' mm, 摩擦风速U*= '+str(round(Uf,3))+' m/s'])
     else:
-        section2.extend(['水域风速KEYPS廓线参数： 粗糙度z0='+str(round(z0*1000,2))+'mm, 摩擦风速U*='+str(round(Uf,3))+'m/s, 修改后的Obukhov稳定长度L\u2032='+str(round(Lp,3))+'m'])
+        section2.extend(['水域风速KEYPS廓线参数： 粗糙度z0= '+str(round(z0*1000,2))+' mm, 摩擦风速U*= '+str(round(Uf,3))+' m/s, 修改后的Obukhov稳定长度L\u2032= '+str(round(Lp,3))+' m'])
         # nn=nn+1
-        section2.extend(['水域风速B-D廓线参数： z0='+str(round(z02*1000,2))+'mm, U*='+str(round(Uf2,3))+'m/s, Obukhov稳定长度L='+str(round(L,3))+'m,'+'梯度Richardson数Ri='+str(round(Ri2,3))])
+        section2.extend(['水域风速B-D廓线参数： z0= '+str(round(z02*1000,2))+' mm, U*= '+str(round(Uf2,3))+' m/s, Obukhov稳定长度L= '+str(round(L,3))+' m,'+'梯度Richardson数Ri= '+str(round(Ri2,3))])
         if ssBD1==1:
             # nn=nn+1
             if o2==1 or o2==2:  
                 section2.extend(['在迭代求解B-D廓线时，由于求得的Ri出现了一个大于0.2的值，计算程序令Ri=0.199, 据此求得其它参数，并终止迭代。'])
             if o2==3 or o2==4:
-                section2.extend(['在迭代求解B-D廓线时，由于求得的Ri出现了一个大于0.2的值，计算程序令Ri=0.199, 令大气边界层阻力定律中的稳定性参数\u03BC='+round(miu2,1)+', 据此求得其它参数，并终止迭代。'])            
+                section2.extend(['在迭代求解B-D廓线时，由于求得的Ri出现了一个大于0.2的值，计算程序令Ri=0.199, 令大气边界层阻力定律中的稳定性参数\u03BC= '+round(miu2,1)+', 据此求得其它参数，并终止迭代。'])            
 
     if o2==4 or o2==3:
         # nn=nn+1
         section2.extend(['大气边界层阻力定律参数'])    
-        section2.extend(['Coriolis参数='+str(round(fCo,7))+'rad/s'])
+        section2_note.extend(['Coriolis参数= '+str(round(fCo,7))+' rad/s'])
         if dT==0:
-            section2.extend(['地转风与近水面风之间的夹角\u03B8='+str(round(180*theta/math.pi,2))+'\u00B0, 稳定性参数\u03BC='+str(round(miu,1))+', A(\u03BC)='+str(round(A(miu),2))+', B(\u03BC)='+str(round(B(miu),2))])
+            section2_note.extend(['地转风与近水面风之间的夹角\u03B8= '+str(round(180*theta/math.pi,2))+' \u00B0, 稳定性参数\u03BC= '+str(round(miu,1))+', A(\u03BC)= '+str(round(A(miu),2))+', B(\u03BC)= '+str(round(B(miu),2))])
         else:        
-            section2.extend(['结合KEYPS廓线： 地转风与近水面风之间的夹角\u03B8='+str(round(180*theta/math.pi,2))+'\u00B0, 稳定性参数\u03BC='+str(round(miu,1))+', A(\u03BC)='+str(round(A(miu),2))+', B(\u03BC)='+str(round(B(miu),2))])
-            section2.extend(['结合B-D廓线： \u03B8='+str(round(180*theta2/math.pi,2))+'\u00B0, \u03BC='+str(round(miu2,1))+', A(\u03BC)='+str(round(A(miu2),2))+', B(\u03BC)='+str(round(B(miu2),2))])
+            section2_note.extend(['结合KEYPS廓线： 地转风与近水面风之间的夹角\u03B8= '+str(round(180*theta/math.pi,2))+' \u00B0, 稳定性参数\u03BC= '+str(round(miu,1))+' , A(\u03BC)= '+str(round(A(miu),2))+' , B(\u03BC)= '+str(round(B(miu),2))])
+            section2_note.extend(['结合B-D廓线： \u03B8= '+str(round(180*theta2/math.pi,2))+' \u00B0, \u03BC= '+str(round(miu2,1))+' , A(\u03BC)= '+str(round(A(miu2),2))+' , B(\u03BC)= '+str(round(B(miu2),2))])
 
     plt.plot([min(0,TaaC-0.5),Uu],[10,10],color='grey',linestyle='--',linewidth=0.5)
     plt.scatter(Up1[10],10,c="None",marker="o",s=50,edgecolors="red",label=str(round(wdu))+'-min $U_{10}$（滨水工）')
@@ -534,12 +535,12 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             Ua1=U*math.log10(10/.03)/math.log10(zw/.03)
             if zw!=10:
                 # nn=nn+1
-                section3.extend(['按第7.1.2.2条求得'+str(round(atm,1))+'-min时距的U\u2081\u2080='+str(round(Ua1,3))+'m/s'])   
+                section3.extend(['按第7.1.2.2条求得 '+str(round(atm,1))+'-min时距的U\u2081\u2080= '+str(round(Ua1,3))+' m/s'])   
                 
         if o2==4:
             Ua1=(.7-0.01*dT)*U  
             # nn=nn+1
-            section3.extend(['按图7.1.3估计海面风速='+str(round(Ua1,3))+'m/s。在此假设该图中的"海面风速"系指U\u2081\u2080。图7.1.3适用于海域。对于大湖和大型水库，建议采用相关有效方法，JTS 145-2015的结果在此仅作参考。'])
+            section3.extend(['按图7.1.3估计海面风速= '+str(round(Ua1,3))+' m/s。在此假设该图中的"海面风速"系指U\u2081\u2080。图7.1.3适用于海域。对于大湖和大型水库，建议采用相关有效方法，JTS 145-2015的结果在此仅作参考。'])
                 
     if ss1!=1:  
         plt.scatter(Ua1,10,c="None",edgecolor='purple',marker="p",s=60,label=str(round(wdu))+'-min $U_{10}$ (JTS 145-2015)')
@@ -554,9 +555,9 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
         if zw!=10:
             # nn=nn+1
             if o2==3:
-               section4.extend(['按公式(3-26)求得地面以上10m处的风速：'+str(round(Ue2,3))+'m/s'])
+               section4.extend(['按公式(3-26)求得地面以上10m处的风速：'+str(round(Ue2,3))+' m/s'])
             else:
-                section4.extend(['按公式(3-26)求得'+str(round(atm,1))+'-min时距的U\u2081\u2080='+str(round(Ue2,3))+'m/s'])        
+                section4.extend(['按公式(3-26)求得 '+str(round(atm,1))+'-min时距的U\u2081\u2080= '+str(round(Ue2,3))+' m/s'])        
             if zw>=20:
                 # nn=nn+1
                 section4.extend(['警告：SPM 1984建议在风速高度低于20 m时使用公式(3-26)，但本例中已知风速的高度并不低于20 m。'])
@@ -566,16 +567,16 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             if X<16:
                 Uel2=1.2*Ue2
                 # nn=nn+1
-                section4.extend(['按第3-IV-3-(c)条,陆-水转换系数RL=1.2,由陆上风估计的U\u2081\u2080='+str(round(Uel2,3))+'m/s。'])                      
+                section4.extend(['按第3-IV-3-(c)条,陆-水转换系数RL=1.2,由陆上风估计的U\u2081\u2080= '+str(round(Uel2,3))+' m/s。'])                      
             else:
                 RL=(0.04*0.0357*Ue2**2-0.2*0.3423*Ue2+1.724)*(Ue2<=18.5)+0.9*(Ue2>18.5)
                 Uel2=Ue2*RL
                 # nn=nn+1
-                section4.extend(['按图3-15，陆-水转换系数RL='+str(round(RL,2))+'，对应的U\u2081\u2080='+str(round(Uel2,3))+'(m/s)'])                       
+                section4.extend(['按图3-15，陆-水转换系数RL= '+str(round(RL,2))+'，对应的U\u2081\u2080= '+str(round(Uel2,3))+' (m/s)'])                       
     else:
         Uel2=U*0.89/U**0.192 # at 10 m elevation (by Figure 3-19)
         # nn=nn+1
-        section4.extend(['按图3-19，Rg='+str(round(0.89/U**0.192,2))+'，由Ug估计的U\u2081\u2080='+str(round(Uel2,3))+'m/s。'])
+        section4.extend(['按图3-19，Rg= '+str(round(0.89/U**0.192,2))+' ，由Ug估计的U\u2081\u2080= '+str(round(Uel2,3))+' m/s。'])
 
     if dT==0:
         RT=1.0
@@ -583,14 +584,14 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
         RT=1-dT*(abs(dT)/1900)**(1/3)/abs(dT) # stability ((by Figure 3-14)   
     Uels2=Uel2*RT    
     # nn=nn+1
-    section4.extend(['按图3-14，RT='+str(round(RT,2))+'，考虑大气稳定性以后的U\u2081\u2080='+str(round(Uels2,3))+'m/s'])
+    section4.extend(['按图3-14，RT= '+str(round(RT,2))+' ，考虑大气稳定性以后的U\u2081\u2080= '+str(round(Uels2,3))+' m/s'])
 
     # Duration adjustment for required averaging time
     if atm!=wdu:
         U1021h=att(Uels2,atm,60)
         U102=att(Uels2,atm,wdu)   
         # nn=nn+1
-        section4.extend(['按图3-13，1-h时距的U\u2081\u2080='+str(round(U1021h,3))+'m/s，而'+str(round(wdu,1))+'-min时距的U\u2081\u2080='+str(round(U102,3))+'m/s。'])        
+        section4.extend(['按图3-13，1-h时距的U\u2081\u2080= '+str(round(U1021h,3))+' m/s，而 '+str(round(wdu,1))+'-min时距的U\u2081\u2080= '+str(round(U102,3))+' m/s。'])        
     else:
         U102=Uels2
 
@@ -618,9 +619,9 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
             if zw!=10:
                 # nn=nn+1
                 if o2==3:
-                    section5.extend(['按公式(II-2-28)求得地面以上10m处的风速：'+str(round(Ue3,3))+'m/s'])
+                    section5.extend(['按公式(II-2-28)求得地面以上10m处的风速：'+str(round(Ue3,3))+' m/s'])
                 else:
-                    section5.extend(['按公式(II-2-28)求得'+str(round(atm,1))+'-min时距的U\u2081\u2080='+str(round(Ue3,3))+'m/s'])        
+                    section5.extend(['按公式(II-2-28)求得 '+str(round(atm,1))+'-min时距的U\u2081\u2080= '+str(round(Ue3,3))+' m/s'])        
                 if zw<8 or zw>12:
                     # nn=nn+1
                     section5.extend(['警告：CEM 2015建议当风速高度在8~12 m之间时使用公式(II-2-28)，但本例中已知风速的高度并未在这一范围。'])
@@ -630,16 +631,16 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
                 if X<16:
                     Uel3=1.2*Ue3
                     # nn=nn+1
-                    section5.extend(['按图II-2-20，陆-水转换系数RL=1.2,由陆上风估计的U\u2081\u2080='+str(round(Uel3,3))+'m/s。'])                      
+                    section5.extend(['按图II-2-20，陆-水转换系数RL=1.2,由陆上风估计的U\u2081\u2080= '+str(round(Uel3,3))+' m/s。'])                      
                 else:
                     RL=(0.04*0.0357*Ue3**2-0.2*0.3423*Ue3+1.724)*(Ue3<=18.5)+0.9*(Ue3>18.5)
                     Uel3=Ue3*RL
                     # nn=nn+1
-                    section5.extend(['按图II-2-20和图II-2-7，陆-水转换系数RL='+str(round(RL,2))+'，对应的U\u2081\u2080='+str(round(Uel3,3))+'(m/s)'])                       
+                    section5.extend(['按图II-2-20和图II-2-7，陆-水转换系数RL= '+str(round(RL,2))+' ，对应的U\u2081\u2080= '+str(round(Uel3,3))+' (m/s)'])                       
         else:
             Uel3=Rg*Ug # at 10 m elevation (by Figure II-2-13)
             # nn=nn+1
-            section5.extend(['按图II-2-13，由Ug估计的U\u2081\u2080='+str(round(Uel3,3))+'m/s。'])
+            section5.extend(['按图II-2-13，由Ug估计的U\u2081\u2080= '+str(round(Uel3,3))+' m/s。'])
 
         if dT==0:
             RT=1.0
@@ -651,13 +652,13 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
         if o2!=4 or (o2==4 and  Rg!=None):   
             U103=Uel3*RT
             # nn=nn+1
-            section5.extend(['按图II-2-20，RT='+str(round(RT,2))+'，考虑大气稳定性以后的U\u2081\u2080='+str(round(U103,3))+'m/s。(RT可按气水温差\u0394T在图II-2-8中读取，该图由ACES软件生成。然而，该图未明确说明气温的高度，且该软件中某些参数的取值有待进一步核实。故在此RT采用图II-2-20中建议的简易取值。）'])
+            section5.extend(['按图II-2-20，RT= '+str(round(RT,2))+' ，考虑大气稳定性以后的U\u2081\u2080= '+str(round(U103,3))+' m/s。(RT可按气水温差\u0394T在图II-2-8中读取，该图由ACES软件生成。然而，该图未明确说明气温的高度，且该软件中某些参数的取值有待进一步核实。故在此RT采用图II-2-20中建议的简易取值。）'])
                             # Duration adjustment for required averaging time
             if atm!=wdu:
                 U1031h=att(U103,atm,60)
                 Ua3=att(U103,atm,wdu) 
                 # nn=nn+1
-                section5.extend(['按图II-2-1，1-h时距的U\u2081\u2080='+str(round(U1031h,3))+'m/s，而'+str(round(wdu,1))+'-min时距的U\u2081\u2080='+str(round(Ua3,3))+'m/s。'])        
+                section5.extend(['按图II-2-1，1-h时距的U\u2081\u2080= '+str(round(U1031h,3))+' m/s，而 '+str(round(wdu,1))+'-min时距的U\u2081\u2080= '+str(round(Ua3,3))+' m/s。'])        
             else:
                 Ua3=U103
         plt.scatter(Ua3,10,c="None",marker="v",s=50,edgecolors="limegreen",label=str(round(wdu))+'-min $U_{10}$ (CEM)')
@@ -758,4 +759,4 @@ def windspeed(o2, zw, Xlat, X, Rg, U, atm, Ta, zt, Tw, TaaC, wdu, zu):
     img_stream = base64.b64encode(img.getvalue()).decode()
     plt.close("all")
 
-    return img_stream, heading, section1, section2, section3, section4, section5, section6, section7, ending
\ No newline at end of file
+    return img_stream, heading, section1, section2, section2_note, section3, section4, section5, section6, section7, ending
\ No newline at end of file
